@@ -2,7 +2,7 @@
 from .env_settings import BaseSettings
 from .error_wrappers import ValidationError
 from .errors import *
-from .fields import Required
+from .fields import Required, Schema
 from .main import BaseConfig, BaseModel, create_model, validator
 from .parse import Protocol
 from .types import *
