@@ -2,6 +2,8 @@ from decimal import Decimal
 from pathlib import Path
 from typing import Union
 
+from .utils import display_as_type
+
 
 class PydanticErrorMixin:
     code: str
@@ -225,3 +227,11 @@ class UUIDVersionError(PydanticValueError):
 
     def __init__(self, *, required_version: int) -> None:
         super().__init__(required_version=required_version)
+
+
+class ArbitraryTypeError(PydanticTypeError):
+    code = 'arbitrary_type'
+    msg_template = 'instance of {expected_arbitrary_type} expected'
+
+    def __init__(self, *, expected_arbitrary_type) -> None:
+        super().__init__(expected_arbitrary_type=display_as_type(expected_arbitrary_type))
